## Utilities

<!-- prettier-ignore-start -->
::: breathe_design.utilities
    handler: python
    options:
      # Presentation
      show_source: false                 # cleaner launch page
      show_signature: true
      separate_signature: true           # wrap long signatures on their own line
      line_length: 88                    # pleasant wrapping width
      show_signature_annotations: false  # hide verbose type hints to reduce noise
      annotations_path: brief            # brief paths when annotations are shown
<!-- prettier-ignore-end -->
